#!/usr/bin/env bash

echo "Building assets"
cd debian/makehuman-data/usr/share/makehuman/
python download_assets.py
./cleannpz.sh
./cleanpyc.sh
python compile_targets.py
python compile_models.py
#python compile_proxies.py
exit 0
